.. super_resolution documentation master file. You can adapt this file completely
   to your liking, but it should at least contain the root `toctree`
   directive.

Welcome to super_resolution's documentation!
==================================

.. toctree::
   :maxdepth: 2

   modules

* :ref:`genindex`
